# eric7.WebBrowser.Navigation.NavigationContainer

Module implementing the navigation container widget.

### Global Attributes

None

### Classes

NavigationContainer | Class implementing the navigation container widget.

### Functions

None

## NavigationContainer

Class implementing the navigation container widget.

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

NavigationContainer | Constructor
addWidget | Public method to add a widget to the container.

### Static Methods

None

#### NavigationContainer (Constructor)

NavigationContainer(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### NavigationContainer.addWidget

addWidget(widget)

Public method to add a widget to the container.

widget (QWidget)
  reference to the widget to be added

Up